[longomatch/redesign2: 33/140] Refactor namespace of database entities to LongoMatch.Store



commit 40fc8c889e82a7a99d9e5e9df7ae665b34ae65ab
Author: Andoni Morales Alastruey <ylatuya gmail com>
Date:   Tue Dec 21 23:01:49 2010 +0100

    Refactor namespace of database entities to LongoMatch.Store
    
    the database entitites are moved from LongoMatch.TimeNodes to
    LongoMatch.Store and the templates moved from LongoMatch.DB to
    LongoMatch.Store.Templates

 LongoMatch/DB/DataBase.cs                          |   11 ++--
 LongoMatch/Gui/Component/ButtonsWidget.cs          |    6 +-
 LongoMatch/Gui/Component/CategoryProperties.cs     |    2 +-
 LongoMatch/Gui/Component/NotesWidget.cs            |    2 +-
 LongoMatch/Gui/Component/PlayListWidget.cs         |    2 +-
 LongoMatch/Gui/Component/PlayerProperties.cs       |    2 +-
 LongoMatch/Gui/Component/PlayersListTreeWidget.cs  |    8 +--
 LongoMatch/Gui/Component/PlaysListTreeWidget.cs    |    8 ++--
 LongoMatch/Gui/Component/ProjectDetailsWidget.cs   |   12 ++--
 LongoMatch/Gui/Component/ProjectListWidget.cs      |    2 +-
 LongoMatch/Gui/Component/ProjectTemplateWidget.cs  |   12 ++--
 LongoMatch/Gui/Component/TaggerWidget.cs           |    5 +-
 LongoMatch/Gui/Component/TagsTreeWidget.cs         |    4 +-
 LongoMatch/Gui/Component/TeamTemplateWidget.cs     |   10 ++--
 LongoMatch/Gui/Component/TimeAdjustWidget.cs       |    2 +-
 LongoMatch/Gui/Component/TimeLineWidget.cs         |    5 +-
 LongoMatch/Gui/Component/TimeReferenceWidget.cs    |    2 +-
 LongoMatch/Gui/Component/TimeScale.cs              |    2 +-
 LongoMatch/Gui/Dialog/DrawingTool.cs               |    2 +-
 LongoMatch/Gui/Dialog/EditCategoryDialog.cs        |    2 +-
 LongoMatch/Gui/Dialog/EditPlayerDialog.cs          |    2 +-
 LongoMatch/Gui/Dialog/HotKeySelectorDialog.cs      |    2 +-
 LongoMatch/Gui/Dialog/NewProjectDialog.cs          |    3 +-
 LongoMatch/Gui/Dialog/OpenProjectDialog.cs         |    3 +-
 LongoMatch/Gui/Dialog/PlayersSelectionDialog.cs    |    5 +-
 .../Gui/Dialog/ProjectTemplateEditorDialog.cs      |    3 +-
 LongoMatch/Gui/Dialog/ProjectsManager.cs           |    6 +--
 LongoMatch/Gui/Dialog/SnapshotsDialog.cs           |    2 +-
 LongoMatch/Gui/Dialog/TaggerDialog.cs              |    4 +-
 LongoMatch/Gui/Dialog/TeamTemplateEditor.cs        |    2 +-
 LongoMatch/Gui/Dialog/TemplatesEditor.cs           |    5 +-
 LongoMatch/Gui/MainWindow.cs                       |   10 ++--
 LongoMatch/Gui/TreeView/CategoriesTreeView.cs      |    2 +-
 LongoMatch/Gui/TreeView/ListTreeViewBase.cs        |    2 +-
 LongoMatch/Gui/TreeView/PlayListTreeView.cs        |    2 +-
 .../Gui/TreeView/PlayerPropertiesTreeView.cs       |    2 +-
 LongoMatch/Gui/TreeView/PlayersTreeView.cs         |    2 +-
 LongoMatch/Gui/TreeView/PlaysTreeView.cs           |    2 +-
 LongoMatch/Gui/TreeView/TagsTreeView.cs            |    2 +-
 LongoMatch/Handlers/EventsManager.cs               |   16 ++----
 LongoMatch/Handlers/Handlers.cs                    |    2 +-
 LongoMatch/Handlers/HotKeysManager.cs              |    7 +--
 LongoMatch/Handlers/VideoDrawingsManager.cs        |    2 +-
 LongoMatch/IO/CSVExport.cs                         |    2 +-
 LongoMatch/IO/SectionsReader.cs                    |    7 +--
 LongoMatch/IO/SectionsWriter.cs                    |    6 +--
 LongoMatch/LongoMatch.mdp                          |   53 +++++++++++++------
 LongoMatch/Main.cs                                 |    8 +--
 LongoMatch/Playlist/IPlayList.cs                   |    2 +-
 LongoMatch/Playlist/PlayList.cs                    |    2 +-
 LongoMatch/{Time => Store}/Category.cs             |    2 +-
 LongoMatch/{Time => Store}/Drawing.cs              |    2 +-
 LongoMatch/{Time => Store}/DrawingsList.cs         |    2 +-
 LongoMatch/{Time => Store}/HotKey.cs               |    4 +-
 LongoMatch/{Time => Store}/PixbufTimeNode.cs       |    2 +-
 LongoMatch/{Time => Store}/Play.cs                 |    4 +-
 LongoMatch/{Time => Store}/PlayListPlay.cs         |    2 +-
 LongoMatch/{Time => Store}/Player.cs               |    2 +-
 LongoMatch/{DB => Store}/Project.cs                |   17 +++---
 LongoMatch/{DB => Store}/ProjectDescription.cs     |    5 +-
 LongoMatch/{Time => Store}/Tag.cs                  |    2 +-
 .../{DB => Store/Templates}/CategoriesTemplate.cs  |    3 +-
 LongoMatch/{DB => Store/Templates}/TagsTemplate.cs |    3 +-
 LongoMatch/{DB => Store/Templates}/TeamTemplate.cs |    7 +--
 LongoMatch/{DB => Store/Templates}/Template.cs     |    3 +-
 LongoMatch/{Time => Store}/Time.cs                 |    2 +-
 LongoMatch/{Time => Store}/TimeNode.cs             |    6 +-
 LongoMatch/Utils/ProjectUtils.cs                   |    2 +-
 68 files changed, 161 insertions(+), 178 deletions(-)
---
diff --git a/LongoMatch/DB/DataBase.cs b/LongoMatch/DB/DataBase.cs
index 69f308b..9f242ba 100644
--- a/LongoMatch/DB/DataBase.cs
+++ b/LongoMatch/DB/DataBase.cs
@@ -19,17 +19,16 @@
 //
 
 using System;
-using System.IO;
 using System.Collections.Generic;
-using System.Reflection;
-using Gtk;
-using Mono.Unix;
 using Db4objects.Db4o;
 using Db4objects.Db4o.Query;
-using LongoMatch.TimeNodes;
+using Gtk;
+using LongoMatch.Common;
 using LongoMatch.Gui;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
 using LongoMatch.Video.Utils;
-using LongoMatch.Common;
+using Mono.Unix;
 
 namespace LongoMatch.DB
 {
diff --git a/LongoMatch/Gui/Component/ButtonsWidget.cs b/LongoMatch/Gui/Component/ButtonsWidget.cs
index f6976a5..6b9d1b8 100644
--- a/LongoMatch/Gui/Component/ButtonsWidget.cs
+++ b/LongoMatch/Gui/Component/ButtonsWidget.cs
@@ -19,12 +19,12 @@
 //
 
 using System;
+using System.Collections.Generic;
 using Gtk;
-using LongoMatch.DB;
 using LongoMatch.Common;
 using LongoMatch.Handlers;
-using LongoMatch.TimeNodes;
-using System.Collections.Generic;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
 
 namespace LongoMatch.Gui.Component
 {
diff --git a/LongoMatch/Gui/Component/CategoryProperties.cs b/LongoMatch/Gui/Component/CategoryProperties.cs
index ff3dba1..f5a7d58 100644
--- a/LongoMatch/Gui/Component/CategoryProperties.cs
+++ b/LongoMatch/Gui/Component/CategoryProperties.cs
@@ -22,7 +22,7 @@ using System;
 using Gdk;
 using Gtk;
 using Mono.Unix;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Gui.Dialog;
 
 namespace LongoMatch.Gui.Component
diff --git a/LongoMatch/Gui/Component/NotesWidget.cs b/LongoMatch/Gui/Component/NotesWidget.cs
index e4fdbca..a94aa27 100644
--- a/LongoMatch/Gui/Component/NotesWidget.cs
+++ b/LongoMatch/Gui/Component/NotesWidget.cs
@@ -20,7 +20,7 @@
 
 using System;
 using Gtk;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Handlers;
 
 namespace LongoMatch.Gui.Component
diff --git a/LongoMatch/Gui/Component/PlayListWidget.cs b/LongoMatch/Gui/Component/PlayListWidget.cs
index ca53494..bb85be2 100644
--- a/LongoMatch/Gui/Component/PlayListWidget.cs
+++ b/LongoMatch/Gui/Component/PlayListWidget.cs
@@ -25,7 +25,7 @@ using LongoMatch.Video.Editor;
 using Mono.Unix;
 using System.IO;
 using LongoMatch.Handlers;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Video.Player;
 using LongoMatch.Video;
 using LongoMatch.Video.Common;
diff --git a/LongoMatch/Gui/Component/PlayerProperties.cs b/LongoMatch/Gui/Component/PlayerProperties.cs
index 3134eeb..c2525d0 100644
--- a/LongoMatch/Gui/Component/PlayerProperties.cs
+++ b/LongoMatch/Gui/Component/PlayerProperties.cs
@@ -21,7 +21,7 @@ using System.IO;
 using Gtk;
 using Gdk;
 using Mono.Unix;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Gui.Popup;
 using LongoMatch.Gui.Dialog;
 
diff --git a/LongoMatch/Gui/Component/PlayersListTreeWidget.cs b/LongoMatch/Gui/Component/PlayersListTreeWidget.cs
index 574b0d9..2ed8707 100644
--- a/LongoMatch/Gui/Component/PlayersListTreeWidget.cs
+++ b/LongoMatch/Gui/Component/PlayersListTreeWidget.cs
@@ -16,14 +16,12 @@
 //  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 //
 
-using System;
 using System.Collections.Generic;
 using Gtk;
-using Mono.Unix;
-using LongoMatch.DB;
-using LongoMatch.Handlers;
-using LongoMatch.TimeNodes;
 using LongoMatch.Common;
+using LongoMatch.Handlers;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
 
 
 namespace LongoMatch.Gui.Component
diff --git a/LongoMatch/Gui/Component/PlaysListTreeWidget.cs b/LongoMatch/Gui/Component/PlaysListTreeWidget.cs
index 257c9f5..403e58d 100644
--- a/LongoMatch/Gui/Component/PlaysListTreeWidget.cs
+++ b/LongoMatch/Gui/Component/PlaysListTreeWidget.cs
@@ -24,7 +24,7 @@ using Gtk;
 using Mono.Unix;
 using LongoMatch.DB;
 using LongoMatch.Handlers;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Common;
 
 namespace LongoMatch.Gui.Component
@@ -160,19 +160,19 @@ namespace LongoMatch.Gui.Component
 				PlayListNodeAdded(tNode);
 		}
 
-		protected virtual void OnSnapshotSeriesEvent(LongoMatch.TimeNodes.Play tNode)
+		protected virtual void OnSnapshotSeriesEvent(LongoMatch.Store.Play tNode)
 		{
 			if (SnapshotSeriesEvent != null)
 				SnapshotSeriesEvent(tNode);
 		}
 
-		protected virtual void OnPlayersTagged(LongoMatch.TimeNodes.Play tNode, Team team)
+		protected virtual void OnPlayersTagged(LongoMatch.Store.Play tNode, Team team)
 		{
 			if (PlayersTagged != null)
 				PlayersTagged(tNode,team);
 		}
 
-		protected virtual void OnTagPlay (LongoMatch.TimeNodes.Play tNode)
+		protected virtual void OnTagPlay (LongoMatch.Store.Play tNode)
 		{
 			if (TagPlay != null)
 				TagPlay(tNode);
diff --git a/LongoMatch/Gui/Component/ProjectDetailsWidget.cs b/LongoMatch/Gui/Component/ProjectDetailsWidget.cs
index 8a8b77a..217e334 100644
--- a/LongoMatch/Gui/Component/ProjectDetailsWidget.cs
+++ b/LongoMatch/Gui/Component/ProjectDetailsWidget.cs
@@ -20,18 +20,18 @@
 
 using System;
 using System.Collections.Generic;
-using Mono.Unix;
 using Gtk;
 using LongoMatch.Common;
-using LongoMatch.DB;
+using LongoMatch.Gui.Dialog;
+using LongoMatch.Gui.Popup;
 using LongoMatch.Handlers;
 using LongoMatch.IO;
-using LongoMatch.Gui.Popup;
-using LongoMatch.Gui.Dialog;
-using LongoMatch.TimeNodes;
-using LongoMatch.Video.Utils;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
 using LongoMatch.Video.Capturer;
 using LongoMatch.Video.Common;
+using LongoMatch.Video.Utils;
+using Mono.Unix;
 
 namespace LongoMatch.Gui.Component
 {
diff --git a/LongoMatch/Gui/Component/ProjectListWidget.cs b/LongoMatch/Gui/Component/ProjectListWidget.cs
index 51f65dc..0ff9597 100644
--- a/LongoMatch/Gui/Component/ProjectListWidget.cs
+++ b/LongoMatch/Gui/Component/ProjectListWidget.cs
@@ -26,7 +26,7 @@ using Gtk;
 using Db4objects.Db4o;
 using LongoMatch.DB;
 using LongoMatch.Handlers;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Video.Utils;
 
 
diff --git a/LongoMatch/Gui/Component/ProjectTemplateWidget.cs b/LongoMatch/Gui/Component/ProjectTemplateWidget.cs
index 5165270..6e01435 100644
--- a/LongoMatch/Gui/Component/ProjectTemplateWidget.cs
+++ b/LongoMatch/Gui/Component/ProjectTemplateWidget.cs
@@ -17,15 +17,15 @@
 //
 //
 using System;
-using System.IO;
 using System.Collections.Generic;
-using Gtk;
-using Mono.Unix;
+using System.IO;
 using Gdk;
-using LongoMatch.DB;
-using LongoMatch.TimeNodes;
+using Gtk;
 using LongoMatch.Gui.Dialog;
 using LongoMatch.IO;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
+using Mono.Unix;
 
 
 namespace LongoMatch.Gui.Component
@@ -187,7 +187,7 @@ namespace LongoMatch.Gui.Component
 			EditSelectedSection();
 		}
 
-		protected virtual void OnCategoriestreeviewSectionClicked(LongoMatch.TimeNodes.Category tNode)
+		protected virtual void OnCategoriestreeviewSectionClicked(LongoMatch.Store.Category tNode)
 		{
 			EditSelectedSection();
 		}
diff --git a/LongoMatch/Gui/Component/TaggerWidget.cs b/LongoMatch/Gui/Component/TaggerWidget.cs
index ae83837..914c4bb 100644
--- a/LongoMatch/Gui/Component/TaggerWidget.cs
+++ b/LongoMatch/Gui/Component/TaggerWidget.cs
@@ -19,9 +19,8 @@
 using System;
 using System.Collections.Generic;
 using Gtk;
-using LongoMatch.TimeNodes;
-using LongoMatch.DB;
-using LongoMatch.Handlers;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
 
 namespace LongoMatch.Gui.Component
 {
diff --git a/LongoMatch/Gui/Component/TagsTreeWidget.cs b/LongoMatch/Gui/Component/TagsTreeWidget.cs
index 75a6374..31ee648 100644
--- a/LongoMatch/Gui/Component/TagsTreeWidget.cs
+++ b/LongoMatch/Gui/Component/TagsTreeWidget.cs
@@ -24,7 +24,7 @@ using Gtk;
 using Mono.Unix;
 using LongoMatch.DB;
 using LongoMatch.Handlers;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 
 namespace LongoMatch.Gui.Component
 {
@@ -232,7 +232,7 @@ namespace LongoMatch.Gui.Component
 				PlayListNodeAdded(tNode);
 		}
 
-		protected virtual void OnSnapshotSeriesEvent(LongoMatch.TimeNodes.Play tNode)
+		protected virtual void OnSnapshotSeriesEvent(LongoMatch.Store.Play tNode)
 		{
 			if (SnapshotSeriesEvent != null)
 				SnapshotSeriesEvent(tNode);
diff --git a/LongoMatch/Gui/Component/TeamTemplateWidget.cs b/LongoMatch/Gui/Component/TeamTemplateWidget.cs
index b48e566..47e0988 100644
--- a/LongoMatch/Gui/Component/TeamTemplateWidget.cs
+++ b/LongoMatch/Gui/Component/TeamTemplateWidget.cs
@@ -16,11 +16,9 @@
 //  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 //
 
-using System;
-using System.Collections.Generic;
 using Gtk;
-using LongoMatch.DB;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
 
 
 namespace LongoMatch.Gui.Component
@@ -71,13 +69,13 @@ namespace LongoMatch.Gui.Component
 			edited = true;
 		}
 
-		protected virtual void OnPlayerpropertiestreeview1PlayerClicked(LongoMatch.TimeNodes.Player player)
+		protected virtual void OnPlayerpropertiestreeview1PlayerClicked(LongoMatch.Store.Player player)
 		{
 			selectedPlayer = player;
 			EditSelectedPlayer();
 		}
 
-		protected virtual void OnPlayerpropertiestreeview1PlayerSelected(LongoMatch.TimeNodes.Player player)
+		protected virtual void OnPlayerpropertiestreeview1PlayerSelected(LongoMatch.Store.Player player)
 		{
 			selectedPlayer = player;
 		}
diff --git a/LongoMatch/Gui/Component/TimeAdjustWidget.cs b/LongoMatch/Gui/Component/TimeAdjustWidget.cs
index 45d8312..a13bb6b 100644
--- a/LongoMatch/Gui/Component/TimeAdjustWidget.cs
+++ b/LongoMatch/Gui/Component/TimeAdjustWidget.cs
@@ -19,7 +19,7 @@
 //
 
 using System;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 
 namespace LongoMatch.Gui.Component
 {
diff --git a/LongoMatch/Gui/Component/TimeLineWidget.cs b/LongoMatch/Gui/Component/TimeLineWidget.cs
index 6abad27..7038339 100644
--- a/LongoMatch/Gui/Component/TimeLineWidget.cs
+++ b/LongoMatch/Gui/Component/TimeLineWidget.cs
@@ -20,10 +20,9 @@
 using System;
 using System.Collections.Generic;
 using Gtk;
-using Gdk;
-using LongoMatch.DB;
 using LongoMatch.Handlers;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
 
 namespace LongoMatch.Gui.Component {
 
diff --git a/LongoMatch/Gui/Component/TimeReferenceWidget.cs b/LongoMatch/Gui/Component/TimeReferenceWidget.cs
index 6d9469e..acb9c90 100644
--- a/LongoMatch/Gui/Component/TimeReferenceWidget.cs
+++ b/LongoMatch/Gui/Component/TimeReferenceWidget.cs
@@ -23,7 +23,7 @@ using Gtk;
 using Gdk;
 using Cairo;
 using LongoMatch.Common;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using Pango;
 
 namespace LongoMatch.Gui.Component
diff --git a/LongoMatch/Gui/Component/TimeScale.cs b/LongoMatch/Gui/Component/TimeScale.cs
index a6aae2d..0922db3 100644
--- a/LongoMatch/Gui/Component/TimeScale.cs
+++ b/LongoMatch/Gui/Component/TimeScale.cs
@@ -27,7 +27,7 @@ using Pango;
 using Mono.Unix;
 using LongoMatch.Common;
 using LongoMatch.Handlers;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 
 namespace LongoMatch.Gui.Component
 {
diff --git a/LongoMatch/Gui/Dialog/DrawingTool.cs b/LongoMatch/Gui/Dialog/DrawingTool.cs
index 1324f9e..d2f27b0 100644
--- a/LongoMatch/Gui/Dialog/DrawingTool.cs
+++ b/LongoMatch/Gui/Dialog/DrawingTool.cs
@@ -21,7 +21,7 @@ using Gdk;
 using Gtk;
 using Mono.Unix;
 using LongoMatch.Gui.Component;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 
 namespace LongoMatch.Gui.Dialog
 {
diff --git a/LongoMatch/Gui/Dialog/EditCategoryDialog.cs b/LongoMatch/Gui/Dialog/EditCategoryDialog.cs
index 631f3e8..02801f3 100644
--- a/LongoMatch/Gui/Dialog/EditCategoryDialog.cs
+++ b/LongoMatch/Gui/Dialog/EditCategoryDialog.cs
@@ -19,7 +19,7 @@
 using System;
 using System.Collections.Generic;
 using Gtk;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Handlers;
 using LongoMatch.Gui.Component;
 using LongoMatch.Gui;
diff --git a/LongoMatch/Gui/Dialog/EditPlayerDialog.cs b/LongoMatch/Gui/Dialog/EditPlayerDialog.cs
index c3723e9..88c177b 100644
--- a/LongoMatch/Gui/Dialog/EditPlayerDialog.cs
+++ b/LongoMatch/Gui/Dialog/EditPlayerDialog.cs
@@ -17,7 +17,7 @@
 //
 
 using System;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 
 namespace LongoMatch.Gui.Dialog
 {
diff --git a/LongoMatch/Gui/Dialog/HotKeySelectorDialog.cs b/LongoMatch/Gui/Dialog/HotKeySelectorDialog.cs
index a4b90c4..bd50113 100644
--- a/LongoMatch/Gui/Dialog/HotKeySelectorDialog.cs
+++ b/LongoMatch/Gui/Dialog/HotKeySelectorDialog.cs
@@ -20,7 +20,7 @@
 using System;
 using Gtk;
 using Gdk;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 
 namespace LongoMatch.Gui.Dialog
 {
diff --git a/LongoMatch/Gui/Dialog/NewProjectDialog.cs b/LongoMatch/Gui/Dialog/NewProjectDialog.cs
index 6a33392..1514d6a 100644
--- a/LongoMatch/Gui/Dialog/NewProjectDialog.cs
+++ b/LongoMatch/Gui/Dialog/NewProjectDialog.cs
@@ -18,10 +18,9 @@
 //
 //
 
-using System;
 using System.Collections.Generic;
-using LongoMatch.DB;
 using LongoMatch.Common;
+using LongoMatch.Store;
 using LongoMatch.Video.Capturer;
 using LongoMatch.Video.Utils;
 
diff --git a/LongoMatch/Gui/Dialog/OpenProjectDialog.cs b/LongoMatch/Gui/Dialog/OpenProjectDialog.cs
index 4ea2875..003eab4 100644
--- a/LongoMatch/Gui/Dialog/OpenProjectDialog.cs
+++ b/LongoMatch/Gui/Dialog/OpenProjectDialog.cs
@@ -18,10 +18,9 @@
 //
 //
 
-using System;
 using System.Collections.Generic;
 using Gtk;
-using LongoMatch.DB;
+using LongoMatch.Store;
 
 namespace LongoMatch.Gui.Dialog
 {
diff --git a/LongoMatch/Gui/Dialog/PlayersSelectionDialog.cs b/LongoMatch/Gui/Dialog/PlayersSelectionDialog.cs
index 3070af8..1f587eb 100644
--- a/LongoMatch/Gui/Dialog/PlayersSelectionDialog.cs
+++ b/LongoMatch/Gui/Dialog/PlayersSelectionDialog.cs
@@ -16,11 +16,10 @@
 //  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 //
 
-using System;
 using System.Collections.Generic;
 using Gtk;
-using LongoMatch.DB;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
 
 namespace LongoMatch.Gui.Dialog
 {
diff --git a/LongoMatch/Gui/Dialog/ProjectTemplateEditorDialog.cs b/LongoMatch/Gui/Dialog/ProjectTemplateEditorDialog.cs
index f8c5d69..0bb3d32 100644
--- a/LongoMatch/Gui/Dialog/ProjectTemplateEditorDialog.cs
+++ b/LongoMatch/Gui/Dialog/ProjectTemplateEditorDialog.cs
@@ -18,7 +18,8 @@
 //
 //
 using System;
-using LongoMatch.DB;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
 
 namespace LongoMatch.Gui.Dialog
 {
diff --git a/LongoMatch/Gui/Dialog/ProjectsManager.cs b/LongoMatch/Gui/Dialog/ProjectsManager.cs
index dd72244..d2c3903 100644
--- a/LongoMatch/Gui/Dialog/ProjectsManager.cs
+++ b/LongoMatch/Gui/Dialog/ProjectsManager.cs
@@ -21,11 +21,9 @@
 using System;
 using System.Collections.Generic;
 using Gtk;
-using Mono.Unix;
 using LongoMatch.Common;
-using LongoMatch.DB;
-using LongoMatch.Gui.Component;
-using LongoMatch.Video.Utils;
+using LongoMatch.Store;
+using Mono.Unix;
 
 namespace LongoMatch.Gui.Dialog
 {
diff --git a/LongoMatch/Gui/Dialog/SnapshotsDialog.cs b/LongoMatch/Gui/Dialog/SnapshotsDialog.cs
index 631e6d3..45129c1 100644
--- a/LongoMatch/Gui/Dialog/SnapshotsDialog.cs
+++ b/LongoMatch/Gui/Dialog/SnapshotsDialog.cs
@@ -19,7 +19,7 @@
 //
 
 using System;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Handlers;
 
 namespace LongoMatch.Gui.Dialog
diff --git a/LongoMatch/Gui/Dialog/TaggerDialog.cs b/LongoMatch/Gui/Dialog/TaggerDialog.cs
index de2f959..9124124 100644
--- a/LongoMatch/Gui/Dialog/TaggerDialog.cs
+++ b/LongoMatch/Gui/Dialog/TaggerDialog.cs
@@ -18,8 +18,8 @@
 
 using System;
 using System.Collections.Generic;
-using LongoMatch.DB;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
 
 namespace LongoMatch.Gui.Dialog
 {
diff --git a/LongoMatch/Gui/Dialog/TeamTemplateEditor.cs b/LongoMatch/Gui/Dialog/TeamTemplateEditor.cs
index 12483a9..53ede37 100644
--- a/LongoMatch/Gui/Dialog/TeamTemplateEditor.cs
+++ b/LongoMatch/Gui/Dialog/TeamTemplateEditor.cs
@@ -17,7 +17,7 @@
 //
 
 using System;
-using LongoMatch.DB;
+using LongoMatch.Store.Templates;
 
 namespace LongoMatch.Gui.Dialog
 {
diff --git a/LongoMatch/Gui/Dialog/TemplatesEditor.cs b/LongoMatch/Gui/Dialog/TemplatesEditor.cs
index d0373bb..ba747fd 100644
--- a/LongoMatch/Gui/Dialog/TemplatesEditor.cs
+++ b/LongoMatch/Gui/Dialog/TemplatesEditor.cs
@@ -20,11 +20,10 @@
 
 using System;
 using System.Collections.Generic;
-using System.IO;
 using Gtk;
-using Mono.Unix;
-using LongoMatch.DB;
 using LongoMatch.IO;
+using LongoMatch.Store.Templates;
+using Mono.Unix;
 
 namespace LongoMatch.Gui.Dialog
 {
diff --git a/LongoMatch/Gui/MainWindow.cs b/LongoMatch/Gui/MainWindow.cs
index d66c15d..cba4be0 100644
--- a/LongoMatch/Gui/MainWindow.cs
+++ b/LongoMatch/Gui/MainWindow.cs
@@ -18,23 +18,21 @@
 //
 //
 
+using System;
+using System.IO;
+using System.Reflection;
 using Gdk;
 using GLib;
 using Gtk;
 using LongoMatch.Common;
-using LongoMatch.DB;
 using LongoMatch.Gui.Dialog;
 using LongoMatch.Handlers;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Utils;
 using LongoMatch.Video.Capturer;
 using LongoMatch.Video.Common;
-using LongoMatch.Video.Player;
 using LongoMatch.Video.Utils;
 using Mono.Unix;
-using System;
-using System.IO;
-using System.Reflection;
 
 
 
diff --git a/LongoMatch/Gui/TreeView/CategoriesTreeView.cs b/LongoMatch/Gui/TreeView/CategoriesTreeView.cs
index 7b390ac..b4ccfdc 100644
--- a/LongoMatch/Gui/TreeView/CategoriesTreeView.cs
+++ b/LongoMatch/Gui/TreeView/CategoriesTreeView.cs
@@ -24,7 +24,7 @@ using Gdk;
 using Gtk;
 using Mono.Unix;
 using LongoMatch.Handlers;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 
 namespace LongoMatch.Gui.Component
 {
diff --git a/LongoMatch/Gui/TreeView/ListTreeViewBase.cs b/LongoMatch/Gui/TreeView/ListTreeViewBase.cs
index 7387a0a..c838beb 100644
--- a/LongoMatch/Gui/TreeView/ListTreeViewBase.cs
+++ b/LongoMatch/Gui/TreeView/ListTreeViewBase.cs
@@ -20,7 +20,7 @@ using Gdk;
 using Gtk;
 using LongoMatch.Common;
 using LongoMatch.Handlers;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using Mono.Unix;
 using System;
 using System.Collections.Generic;
diff --git a/LongoMatch/Gui/TreeView/PlayListTreeView.cs b/LongoMatch/Gui/TreeView/PlayListTreeView.cs
index 8cdcb25..35d78cb 100644
--- a/LongoMatch/Gui/TreeView/PlayListTreeView.cs
+++ b/LongoMatch/Gui/TreeView/PlayListTreeView.cs
@@ -21,7 +21,7 @@ using System;
 using Gtk;
 using Gdk;
 using Mono.Unix;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Playlist;
 using LongoMatch.Handlers;
 using LongoMatch.Gui.Dialog;
diff --git a/LongoMatch/Gui/TreeView/PlayerPropertiesTreeView.cs b/LongoMatch/Gui/TreeView/PlayerPropertiesTreeView.cs
index 514ca91..7f52d07 100644
--- a/LongoMatch/Gui/TreeView/PlayerPropertiesTreeView.cs
+++ b/LongoMatch/Gui/TreeView/PlayerPropertiesTreeView.cs
@@ -23,7 +23,7 @@ using Gdk;
 using Gtk;
 using Mono.Unix;
 using LongoMatch.Handlers;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 
 namespace LongoMatch.Gui.Component
 {
diff --git a/LongoMatch/Gui/TreeView/PlayersTreeView.cs b/LongoMatch/Gui/TreeView/PlayersTreeView.cs
index 0a36674..c8574ad 100644
--- a/LongoMatch/Gui/TreeView/PlayersTreeView.cs
+++ b/LongoMatch/Gui/TreeView/PlayersTreeView.cs
@@ -19,7 +19,7 @@
 using Gdk;
 using Gtk;
 using LongoMatch.Common;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 
 namespace LongoMatch.Gui.Component
 {
diff --git a/LongoMatch/Gui/TreeView/PlaysTreeView.cs b/LongoMatch/Gui/TreeView/PlaysTreeView.cs
index c54f909..8c79534 100644
--- a/LongoMatch/Gui/TreeView/PlaysTreeView.cs
+++ b/LongoMatch/Gui/TreeView/PlaysTreeView.cs
@@ -21,7 +21,7 @@
 using Gdk;
 using Gtk;
 using LongoMatch.Common;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using System;
 
 namespace LongoMatch.Gui.Component
diff --git a/LongoMatch/Gui/TreeView/TagsTreeView.cs b/LongoMatch/Gui/TreeView/TagsTreeView.cs
index 8ae6195..dfdcd02 100644
--- a/LongoMatch/Gui/TreeView/TagsTreeView.cs
+++ b/LongoMatch/Gui/TreeView/TagsTreeView.cs
@@ -20,7 +20,7 @@
 
 using Gdk;
 using Gtk;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 
 namespace LongoMatch.Gui.Component
 {
diff --git a/LongoMatch/Handlers/EventsManager.cs b/LongoMatch/Handlers/EventsManager.cs
index 345d136..2b10ad8 100644
--- a/LongoMatch/Handlers/EventsManager.cs
+++ b/LongoMatch/Handlers/EventsManager.cs
@@ -18,22 +18,18 @@
 //
 //
 
-using System;
 using System.Collections.Generic;
+using Gdk;
+using Gtk;
 using LongoMatch.Common;
+using LongoMatch.Gui;
 using LongoMatch.Gui.Component;
 using LongoMatch.Gui.Dialog;
-using LongoMatch.TimeNodes;
-using LongoMatch.DB;
-using LongoMatch.Video.Player;
+using LongoMatch.Handlers;
+using LongoMatch.Store;
 using LongoMatch.Video.Common;
-using LongoMatch.Video.Utils;
 using LongoMatch.Video.Editor;
-using LongoMatch.Video;
-using LongoMatch.Handlers;
-using LongoMatch.Gui;
-using Gtk;
-using Gdk;
+using LongoMatch.Video.Utils;
 using Mono.Unix;
 
 namespace LongoMatch
diff --git a/LongoMatch/Handlers/Handlers.cs b/LongoMatch/Handlers/Handlers.cs
index b3f62e1..6d9f586 100644
--- a/LongoMatch/Handlers/Handlers.cs
+++ b/LongoMatch/Handlers/Handlers.cs
@@ -22,7 +22,7 @@ using System;
 using System.Collections.Generic;
 using LongoMatch;
 using LongoMatch.DB;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Common;
 
 namespace LongoMatch.Handlers
diff --git a/LongoMatch/Handlers/HotKeysManager.cs b/LongoMatch/Handlers/HotKeysManager.cs
index 0977532..bd15413 100644
--- a/LongoMatch/Handlers/HotKeysManager.cs
+++ b/LongoMatch/Handlers/HotKeysManager.cs
@@ -18,12 +18,11 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 //
 //
-using System;
 using System.Collections.Generic;
-using Gtk;
 using Gdk;
-using LongoMatch.DB;
-using LongoMatch.TimeNodes;
+using Gtk;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
 
 namespace LongoMatch.Handlers
 {
diff --git a/LongoMatch/Handlers/VideoDrawingsManager.cs b/LongoMatch/Handlers/VideoDrawingsManager.cs
index 34b0af0..1f5be03 100644
--- a/LongoMatch/Handlers/VideoDrawingsManager.cs
+++ b/LongoMatch/Handlers/VideoDrawingsManager.cs
@@ -19,7 +19,7 @@
 using System;
 using System.Collections.Generic;
 using Gdk;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Gui;
 using LongoMatch.Video.Common;
 
diff --git a/LongoMatch/IO/CSVExport.cs b/LongoMatch/IO/CSVExport.cs
index 6b2e2c2..cb40ce3 100644
--- a/LongoMatch/IO/CSVExport.cs
+++ b/LongoMatch/IO/CSVExport.cs
@@ -23,7 +23,7 @@ using System.IO;
 using System.Collections.Generic;
 using Gtk;
 using LongoMatch.DB;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Gui;
 using Mono.Unix;
 
diff --git a/LongoMatch/IO/SectionsReader.cs b/LongoMatch/IO/SectionsReader.cs
index 21e5444..1279df5 100644
--- a/LongoMatch/IO/SectionsReader.cs
+++ b/LongoMatch/IO/SectionsReader.cs
@@ -19,12 +19,9 @@
 //
 
 using System;
-using System.Configuration;
-using System.IO;
-using System.Xml;
-using LongoMatch.DB;
 using Gdk;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
 
 namespace LongoMatch.IO
 {
diff --git a/LongoMatch/IO/SectionsWriter.cs b/LongoMatch/IO/SectionsWriter.cs
index 96a816e..e6fc43d 100644
--- a/LongoMatch/IO/SectionsWriter.cs
+++ b/LongoMatch/IO/SectionsWriter.cs
@@ -19,13 +19,11 @@
 //
 
 using System;
-using System.Configuration;
 using System.IO;
 using System.Xml;
 using Mono.Unix;
-using LongoMatch.DB;
-using LongoMatch.TimeNodes;
-using Gdk;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
 
 namespace LongoMatch.IO
 {
diff --git a/LongoMatch/LongoMatch.mdp b/LongoMatch/LongoMatch.mdp
index 5aec8df..2f6db1f 100644
--- a/LongoMatch/LongoMatch.mdp
+++ b/LongoMatch/LongoMatch.mdp
@@ -30,18 +30,11 @@
     <File subtype="Directory" buildaction="Compile" name="Gui" />
     <File subtype="Code" buildaction="Compile" name="Gui/MainWindow.cs" />
     <File subtype="Directory" buildaction="Compile" name="DB" />
-    <File subtype="Code" buildaction="Compile" name="DB/Project.cs" />
     <File subtype="Code" buildaction="Compile" name="DB/DataBase.cs" />
     <File subtype="Directory" buildaction="Compile" name="Handlers" />
     <File subtype="Code" buildaction="Compile" name="Handlers/Handlers.cs" />
     <File subtype="Directory" buildaction="Compile" name="IO" />
     <File subtype="Directory" buildaction="Compile" name="Time" />
-    <File subtype="Code" buildaction="Compile" name="Time/Play.cs" />
-    <File subtype="Code" buildaction="Compile" name="Time/PixbufTimeNode.cs" />
-    <File subtype="Code" buildaction="Compile" name="Time/Category.cs" />
-    <File subtype="Code" buildaction="Compile" name="Time/TimeNode.cs" />
-    <File subtype="Code" buildaction="Compile" name="Time/Time.cs" />
-    <File subtype="Code" buildaction="Compile" name="Time/PlayListPlay.cs" />
     <File subtype="Code" buildaction="EmbedAsResource" name="images/longomatch.png" DeployService.RelativeDeployPath="images/longomatch.png" DeployService.TargetDirectoryId="CommonApplicationDataRoot" />
     <File subtype="Directory" buildaction="Compile" name="images" />
     <File subtype="Code" name="images/background.png" DeployService.Deploy="True" DeployService.RelativeDeployPath="images/background.png" DeployService.TargetDirectoryId="CommonApplicationDataRoot" buildaction="FileCopy" />
@@ -52,13 +45,9 @@
     <File subtype="Code" buildaction="Compile" name="Updates/Updater.cs" />
     <File subtype="Code" buildaction="Compile" name="Updates/XmlUpdateParser.cs" />
     <File subtype="Code" buildaction="Compile" name="IO/CSVExport.cs" />
-    <File subtype="Code" buildaction="Compile" name="Time/HotKey.cs" />
     <File subtype="Code" buildaction="Compile" name="Handlers/EventsManager.cs" />
     <File subtype="Code" buildaction="Compile" name="Handlers/HotKeysManager.cs" />
-    <File subtype="Code" buildaction="Compile" name="DB/TeamTemplate.cs" />
-    <File subtype="Code" buildaction="Compile" name="Time/Player.cs" />
     <File subtype="Code" buildaction="Nothing" name="images/logo_48x48.png" DeployService.RelativeDeployPath="icons/hicolor/48x48/longomatch.png" DeployService.TargetDirectoryId="CommonApplicationDataRoot" />
-    <File subtype="Code" buildaction="Compile" name="DB/TagsTemplate.cs" />
     <File subtype="Code" buildaction="Compile" name="Gui/TransparentDrawingArea.cs" />
     <File subtype="Code" buildaction="Compile" name="Handlers/DrawingManager.cs" />
     <File subtype="Directory" buildaction="Compile" name="Gui/Dialog" />
@@ -106,17 +95,13 @@
     <File subtype="Code" buildaction="Compile" name="Gui/Dialog/TeamTemplateEditor.cs" />
     <File subtype="Code" buildaction="Compile" name="Gui/Component/DrawingWidget.cs" />
     <File subtype="Code" buildaction="Compile" name="Gui/Dialog/DrawingTool.cs" />
-    <File subtype="Code" buildaction="Compile" name="Time/Drawing.cs" />
     <File subtype="Code" buildaction="Compile" name="Handlers/VideoDrawingsManager.cs" />
-    <File subtype="Code" buildaction="Compile" name="Time/DrawingsList.cs" />
-    <File subtype="Code" buildaction="Compile" name="DB/ProjectDescription.cs" />
     <File subtype="Code" buildaction="EmbedAsResource" name="images/stock_draw-circle-unfilled.png" />
     <File subtype="Code" buildaction="EmbedAsResource" name="images/stock_draw-freeform-line.png" />
     <File subtype="Code" buildaction="EmbedAsResource" name="images/stock_draw-line-45.png" />
     <File subtype="Code" buildaction="EmbedAsResource" name="images/stock_draw-line-ends-with-arrow.png" />
     <File subtype="Code" buildaction="EmbedAsResource" name="images/stock_draw-rectangle-unfilled.png" />
     <File subtype="Code" buildaction="Compile" name="Common/Enums.cs" />
-    <File subtype="Code" buildaction="Compile" name="Time/Tag.cs" />
     <File subtype="Code" buildaction="Compile" name="Gui/Component/TaggerWidget.cs" />
     <File subtype="Code" buildaction="Compile" name="Gui/Dialog/TaggerDialog.cs" />
     <File subtype="Code" buildaction="Compile" name="Gui/TreeView/TagsTreeView.cs" />
@@ -179,8 +164,42 @@
     <File subtype="Code" buildaction="Compile" name="IO/XMLReader.cs" />
     <File subtype="Code" buildaction="Compile" name="IO/SectionsReader.cs" />
     <File subtype="Code" buildaction="Compile" name="IO/SectionsWriter.cs" />
-    <File subtype="Code" buildaction="Compile" name="DB/CategoriesTemplate.cs" />
-    <File subtype="Code" buildaction="Compile" name="DB/Template.cs" />
+    <File subtype="Directory" buildaction="Compile" name="Store" />
+    <File subtype="Directory" buildaction="Compile" name="Store/Template" />
+    <File subtype="Code" buildaction="Compile" name="Store/Template/CategoriesTemplate.cs" />
+    <File subtype="Directory" buildaction="Compile" name="DB" />
+    <File subtype="Code" buildaction="Compile" name="Store/Template/TagsTemplate.cs" />
+    <File subtype="Directory" buildaction="Compile" name="DB" />
+    <File subtype="Code" buildaction="Compile" name="Store/Template/TeamTemplate.cs" />
+    <File subtype="Directory" buildaction="Compile" name="DB" />
+    <File subtype="Code" buildaction="Compile" name="Store/Template/Template.cs" />
+    <File subtype="Directory" buildaction="Compile" name="DB" />
+    <File subtype="Code" buildaction="Compile" name="Store/Project.cs" />
+    <File subtype="Directory" buildaction="Compile" name="DB" />
+    <File subtype="Code" buildaction="Compile" name="Store/ProjectDescription.cs" />
+    <File subtype="Directory" buildaction="Compile" name="DB" />
+    <File subtype="Code" buildaction="Compile" name="Store/Category.cs" />
+    <File subtype="Directory" buildaction="Compile" name="Time" />
+    <File subtype="Code" buildaction="Compile" name="Store/Drawing.cs" />
+    <File subtype="Directory" buildaction="Compile" name="Time" />
+    <File subtype="Code" buildaction="Compile" name="Store/DrawingsList.cs" />
+    <File subtype="Directory" buildaction="Compile" name="Time" />
+    <File subtype="Code" buildaction="Compile" name="Store/HotKey.cs" />
+    <File subtype="Directory" buildaction="Compile" name="Time" />
+    <File subtype="Code" buildaction="Compile" name="Store/PixbufTimeNode.cs" />
+    <File subtype="Directory" buildaction="Compile" name="Time" />
+    <File subtype="Code" buildaction="Compile" name="Store/Play.cs" />
+    <File subtype="Directory" buildaction="Compile" name="Time" />
+    <File subtype="Code" buildaction="Compile" name="Store/Player.cs" />
+    <File subtype="Directory" buildaction="Compile" name="Time" />
+    <File subtype="Code" buildaction="Compile" name="Store/PlayListPlay.cs" />
+    <File subtype="Directory" buildaction="Compile" name="Time" />
+    <File subtype="Code" buildaction="Compile" name="Store/Tag.cs" />
+    <File subtype="Directory" buildaction="Compile" name="Time" />
+    <File subtype="Code" buildaction="Compile" name="Store/Time.cs" />
+    <File subtype="Directory" buildaction="Compile" name="Time" />
+    <File subtype="Code" buildaction="Compile" name="Store/TimeNode.cs" />
+    <File subtype="Directory" buildaction="Compile" name="Time" />
   </Contents>
   <References>
     <ProjectReference type="Gac" localcopy="True" refto="Mono.Posix, Version=2.0.0.0, Culture=neutral, PublicKeyToken=0738eb9f132ed756" />
diff --git a/LongoMatch/Main.cs b/LongoMatch/Main.cs
index 216b539..903fbfd 100644
--- a/LongoMatch/Main.cs
+++ b/LongoMatch/Main.cs
@@ -22,14 +22,12 @@
 using System;
 using System.IO;
 using Gtk;
-using Mono.Unix;
 using LongoMatch.Common;
-using LongoMatch.Gui;
-using LongoMatch.Gui.Dialog;
 using LongoMatch.DB;
+using LongoMatch.Gui;
 using LongoMatch.IO;
-using LongoMatch.TimeNodes;
-using System.Runtime.InteropServices;
+using LongoMatch.Store.Templates;
+using Mono.Unix;
 
 namespace LongoMatch
 
diff --git a/LongoMatch/Playlist/IPlayList.cs b/LongoMatch/Playlist/IPlayList.cs
index 095c695..68d6aa3 100644
--- a/LongoMatch/Playlist/IPlayList.cs
+++ b/LongoMatch/Playlist/IPlayList.cs
@@ -21,7 +21,7 @@
 using System;
 using System.Collections;
 using Gtk;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 
 namespace LongoMatch.Playlist {
 
diff --git a/LongoMatch/Playlist/PlayList.cs b/LongoMatch/Playlist/PlayList.cs
index b3415bd..92a31bb 100644
--- a/LongoMatch/Playlist/PlayList.cs
+++ b/LongoMatch/Playlist/PlayList.cs
@@ -25,7 +25,7 @@ using System.IO;
 using System.Runtime.Serialization.Formatters.Binary;
 using System.Xml.Serialization;
 using Gtk;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using Mono.Unix;
 namespace LongoMatch.Playlist
 {
diff --git a/LongoMatch/Time/Category.cs b/LongoMatch/Store/Category.cs
similarity index 95%
rename from LongoMatch/Time/Category.cs
rename to LongoMatch/Store/Category.cs
index f6442a6..7fea588 100644
--- a/LongoMatch/Time/Category.cs
+++ b/LongoMatch/Store/Category.cs
@@ -24,7 +24,7 @@ using Gdk;
 using Mono.Unix;
 using LongoMatch.Common;
 
-namespace LongoMatch.TimeNodes
+namespace LongoMatch.Store
 {
 
 	/// <summary>
diff --git a/LongoMatch/Time/Drawing.cs b/LongoMatch/Store/Drawing.cs
similarity index 98%
rename from LongoMatch/Time/Drawing.cs
rename to LongoMatch/Store/Drawing.cs
index b20bb99..c47126a 100644
--- a/LongoMatch/Time/Drawing.cs
+++ b/LongoMatch/Store/Drawing.cs
@@ -19,7 +19,7 @@
 using System;
 using Gdk;
 
-namespace LongoMatch.TimeNodes
+namespace LongoMatch.Store
 {
 	
 	[Serializable]
diff --git a/LongoMatch/Time/DrawingsList.cs b/LongoMatch/Store/DrawingsList.cs
similarity index 99%
rename from LongoMatch/Time/DrawingsList.cs
rename to LongoMatch/Store/DrawingsList.cs
index f9a2659..7e543cc 100644
--- a/LongoMatch/Time/DrawingsList.cs
+++ b/LongoMatch/Store/DrawingsList.cs
@@ -19,7 +19,7 @@
 using System;
 using System.Collections.Generic;
 
-namespace LongoMatch.TimeNodes
+namespace LongoMatch.Store
 {
 
 
diff --git a/LongoMatch/Time/PixbufTimeNode.cs b/LongoMatch/Store/PixbufTimeNode.cs
similarity index 94%
rename from LongoMatch/Time/PixbufTimeNode.cs
rename to LongoMatch/Store/PixbufTimeNode.cs
index 8cf1544..1aa1107 100644
--- a/LongoMatch/Time/PixbufTimeNode.cs
+++ b/LongoMatch/Store/PixbufTimeNode.cs
@@ -21,7 +21,7 @@
 using System;
 using Gdk;
 
-namespace LongoMatch.TimeNodes
+namespace LongoMatch.Store
 {
 
 	/// <summary>
diff --git a/LongoMatch/Time/Play.cs b/LongoMatch/Store/Play.cs
similarity index 94%
rename from LongoMatch/Time/Play.cs
rename to LongoMatch/Store/Play.cs
index 8cffd1a..2cb46fc 100644
--- a/LongoMatch/Time/Play.cs
+++ b/LongoMatch/Store/Play.cs
@@ -25,7 +25,7 @@ using Mono.Unix;
 using Gdk;
 using LongoMatch.Common;
 
-namespace LongoMatch.TimeNodes
+namespace LongoMatch.Store
 {
 
 	/// <summary>
@@ -108,7 +108,7 @@ namespace LongoMatch.TimeNodes
 		public List<Player> VisitorPlayers {get; set;}
 
 		/// <summary>
-		/// Get/Set the key frame's <see cref="LongoMatch.TimeNodes.Drawing"/>
+		/// Get/Set the key frame's <see cref="LongoMatch.Store.Drawing"/>
 		/// </summary>
 		public Drawing KeyFrameDrawing {get; set;}
 
diff --git a/LongoMatch/Time/PlayListPlay.cs b/LongoMatch/Store/PlayListPlay.cs
similarity index 94%
rename from LongoMatch/Time/PlayListPlay.cs
rename to LongoMatch/Store/PlayListPlay.cs
index 2bc66a9..a3cf33c 100644
--- a/LongoMatch/Time/PlayListPlay.cs
+++ b/LongoMatch/Store/PlayListPlay.cs
@@ -23,7 +23,7 @@ using System.Collections.Generic;
 using Gdk;
 using LongoMatch.Video.Utils;
 
-namespace LongoMatch.TimeNodes
+namespace LongoMatch.Store
 {
 	/// <summary>
 	/// Represents a video segment used by <see cref="LongoMatch.Playlist.Playlist"/>.
diff --git a/LongoMatch/Time/Player.cs b/LongoMatch/Store/Player.cs
similarity index 93%
rename from LongoMatch/Time/Player.cs
rename to LongoMatch/Store/Player.cs
index 45a17fd..062ab58 100644
--- a/LongoMatch/Time/Player.cs
+++ b/LongoMatch/Store/Player.cs
@@ -20,7 +20,7 @@ using System;
 using Gdk;
 using LongoMatch.Common;
 
-namespace LongoMatch.TimeNodes
+namespace LongoMatch.Store
 {
 	/// <summary>
 	/// I am a player from a team
diff --git a/LongoMatch/DB/ProjectDescription.cs b/LongoMatch/Store/ProjectDescription.cs
similarity index 97%
rename from LongoMatch/DB/ProjectDescription.cs
rename to LongoMatch/Store/ProjectDescription.cs
index acccefd..02f0ba7 100644
--- a/LongoMatch/DB/ProjectDescription.cs
+++ b/LongoMatch/Store/ProjectDescription.cs
@@ -17,11 +17,10 @@
 //
 
 using System;
-using Gdk;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Video.Utils;
 
-namespace LongoMatch.DB
+namespace LongoMatch.Store
 {
 
 	/// <summary>
diff --git a/LongoMatch/Time/Tag.cs b/LongoMatch/Store/Tag.cs
similarity index 97%
rename from LongoMatch/Time/Tag.cs
rename to LongoMatch/Store/Tag.cs
index a48ad0f..3eeaad7 100644
--- a/LongoMatch/Time/Tag.cs
+++ b/LongoMatch/Store/Tag.cs
@@ -18,7 +18,7 @@
 
 using System;
 
-namespace LongoMatch.TimeNodes
+namespace LongoMatch.Store
 {
 
 	[Serializable]
diff --git a/LongoMatch/DB/CategoriesTemplate.cs b/LongoMatch/Store/Templates/CategoriesTemplate.cs
similarity index 99%
rename from LongoMatch/DB/CategoriesTemplate.cs
rename to LongoMatch/Store/Templates/CategoriesTemplate.cs
index e708708..dfbbf80 100644
--- a/LongoMatch/DB/CategoriesTemplate.cs
+++ b/LongoMatch/Store/Templates/CategoriesTemplate.cs
@@ -22,9 +22,8 @@ using System.Collections.Generic;
 using System.Linq;
 using Gdk;
 using LongoMatch.Common;
-using LongoMatch.TimeNodes;
 
-namespace LongoMatch.DB
+namespace LongoMatch.Store.Templates
 {
 
 	/// <summary>
diff --git a/LongoMatch/DB/TagsTemplate.cs b/LongoMatch/Store/Templates/TagsTemplate.cs
similarity index 97%
rename from LongoMatch/DB/TagsTemplate.cs
rename to LongoMatch/Store/Templates/TagsTemplate.cs
index 4273084..c11c4ca 100644
--- a/LongoMatch/DB/TagsTemplate.cs
+++ b/LongoMatch/Store/Templates/TagsTemplate.cs
@@ -18,9 +18,8 @@
 
 using System;
 using System.Collections.Generic;
-using LongoMatch.TimeNodes;
 
-namespace LongoMatch.DB
+namespace LongoMatch.Store.Templates
 {
 
 	[Serializable]
diff --git a/LongoMatch/DB/TeamTemplate.cs b/LongoMatch/Store/Templates/TeamTemplate.cs
similarity index 92%
rename from LongoMatch/DB/TeamTemplate.cs
rename to LongoMatch/Store/Templates/TeamTemplate.cs
index 6095b60..270da3f 100644
--- a/LongoMatch/DB/TeamTemplate.cs
+++ b/LongoMatch/Store/Templates/TeamTemplate.cs
@@ -18,14 +18,9 @@
 
 using System;
 using System.Collections.Generic;
-using System.IO;
 using System.Linq;
-using System.Runtime.Serialization;
-using System.Runtime.Serialization.Formatters.Binary;
-using LongoMatch.TimeNodes;
-using LongoMatch.Common;
 
-namespace LongoMatch.DB
+namespace LongoMatch.Store.Templates
 {
 	[Serializable]
 
diff --git a/LongoMatch/DB/Template.cs b/LongoMatch/Store/Templates/Template.cs
similarity index 97%
rename from LongoMatch/DB/Template.cs
rename to LongoMatch/Store/Templates/Template.cs
index 5e8d6f9..b1c7304 100644
--- a/LongoMatch/DB/Template.cs
+++ b/LongoMatch/Store/Templates/Template.cs
@@ -15,12 +15,11 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 // 
-using System;
 using System.IO;
 using System.Runtime.Serialization;
 using System.Runtime.Serialization.Formatters.Binary;
 
-namespace LongoMatch.DB
+namespace LongoMatch.Store.Templates
 {
 	public abstract class Template
 	{
diff --git a/LongoMatch/Time/Time.cs b/LongoMatch/Store/Time.cs
similarity index 95%
rename from LongoMatch/Time/Time.cs
rename to LongoMatch/Store/Time.cs
index a22f777..1209eb6 100644
--- a/LongoMatch/Time/Time.cs
+++ b/LongoMatch/Store/Time.cs
@@ -20,7 +20,7 @@
 
 using System;
 
-namespace LongoMatch.TimeNodes
+namespace LongoMatch.Store
 {
 
 	/// <summary>
diff --git a/LongoMatch/Utils/ProjectUtils.cs b/LongoMatch/Utils/ProjectUtils.cs
index 98aadc1..cdf9588 100644
--- a/LongoMatch/Utils/ProjectUtils.cs
+++ b/LongoMatch/Utils/ProjectUtils.cs
@@ -25,7 +25,7 @@ using LongoMatch.DB;
 using LongoMatch.Gui;
 using LongoMatch.Gui.Dialog;
 using LongoMatch.IO;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Video;
 using LongoMatch.Video.Capturer;
 using LongoMatch.Video.Utils;



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/LongoMatch/Time/HotKey.cs b/LongoMatch/Store/HotKey.cs
similarity index 97%
rename from LongoMatch/Time/HotKey.cs
rename to LongoMatch/Store/HotKey.cs
index 2915a47..43a416a 100644
--- a/LongoMatch/Time/HotKey.cs
+++ b/LongoMatch/Store/HotKey.cs
@@ -27,11 +27,11 @@ using Gtk;
 using Gdk;
 using Mono.Unix;
 
-namespace LongoMatch.TimeNodes
+namespace LongoMatch.Store
 {
 
 	/// <summary>
 	/// A key combination used to tag plays using the keyboard. <see cref="LongoMatch.TimeNodes.SectionsTimeNodes"/>
 	/// It can only be used with the Shith and Alt modifiers to avoid interfering with ohter shortcuts. 
 	/// 'key' and 'modifier' are set to -1 when it's initialized
 	/// </summary>
@@ -27,11 +27,11 @@ using Gtk;
 
 	/// <summary>
-	/// A key combination used to tag plays using the keyboard. <see cref="LongoMatch.TimeNodes.SectionsTimeNodes"/>
+	/// A key combination used to tag plays using the keyboard. <see cref="LongoMatch.Store.SectionsTimeNodes"/>
 	/// It can only be used with the Shith and Alt modifiers to avoid interfering with ohter shortcuts. 
 	/// 'key' and 'modifier' are set to -1 when it's initialized
diff --git a/LongoMatch/DB/Project.cs b/LongoMatch/Store/Project.cs
similarity index 94%
rename from LongoMatch/DB/Project.cs
rename to LongoMatch/Store/Project.cs
index d6de7b6..2c910cf 100644
--- a/LongoMatch/DB/Project.cs
+++ b/LongoMatch/Store/Project.cs
@@ -19,20 +19,19 @@
 //
 
 using System;
-using System.Linq;
-using System.IO;
-using System.Collections;
 using System.Collections.Generic;
+using System.IO;
+using System.Linq;
 using System.Runtime.Serialization;
 using System.Runtime.Serialization.Formatters.Binary;
-using Gtk;
 using Gdk;
-using Mono.Unix;
+using Gtk;
 using LongoMatch.Common;
-using LongoMatch.TimeNodes;
-using LongoMatch.Video.Utils;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
+using Mono.Unix;
 
-namespace LongoMatch.DB
+namespace LongoMatch.Store
 {
 
 	/// <summary>
@@ -43,7 +42,7 @@ namespace LongoMatch.DB
 	/// -1 Categories Template
 	/// -1 Local Team Template
 	/// -1 Visitor Team Template
 	/// -1 list of <see cref="LongoMatch.TimeNodes.MediaTimeNode"/> for each category
 	/// </summary>
 	///
 	[Serializable]
@@ -43,7 +42,7 @@ namespace LongoMatch.DB
 	/// -1 Local Team Template
 	/// -1 Visitor Team Template
-	/// -1 list of <see cref="LongoMatch.TimeNodes.MediaTimeNode"/> for each category
+	/// -1 list of <see cref="LongoMatch.Store.MediaTimeNode"/> for each category
 	/// </summary>
 	///
diff --git a/LongoMatch/Time/TimeNode.cs b/LongoMatch/Store/TimeNode.cs
similarity index 94%
rename from LongoMatch/Time/TimeNode.cs
rename to LongoMatch/Store/TimeNode.cs
index dc0e096..c1f7b5a 100644
--- a/LongoMatch/Time/TimeNode.cs
+++ b/LongoMatch/Store/TimeNode.cs
@@ -20,14 +20,14 @@
 
 using System;
 using System.Collections.Generic;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 
-namespace LongoMatch.TimeNodes
+namespace LongoMatch.Store
 {
 
 	/// <summary>
 	/// Base class for all the time span related objects in the database.
 	/// It has a name that describe it and a start and stop <see cref="LongoMatch.TimeNodes.Time"/>
 	/// </summary>
 	[Serializable]
 	public class TimeNode
@@ -20,14 +20,14 @@
 	/// <summary>
 	/// Base class for all the time span related objects in the database.
-	/// It has a name that describe it and a start and stop <see cref="LongoMatch.TimeNodes.Time"/>
+	/// It has a name that describe it and a start and stop <see cref="LongoMatch.Store.Time"/>
 	/// </summary>
 	[Serializable]